@@ -70,8 +70,8 @@ class HasCompTyKind a where
     compTag :: a -> CompTyKind
 
 -- | Composite type definitions (tags)
-data TagDef =  CompDef CompType	  --definition
-     	       | EnumDef EnumType      -- enum definition
+data TagDef =  CompDef CompType  --composite definition
+             | EnumDef EnumType  --enum definition
                deriving (Typeable, Data {-! ,CNode !-})
 
 instance HasSUERef TagDef where
@@ -111,9 +111,9 @@ instance (Declaration a, Declaration b) => Declaration (Either a b) where
 
 -- | identifiers, typedefs and enumeration constants (namespace sum)
 data IdentDecl = Declaration Decl           -- ^ object or function declaration
-	             | ObjectDef ObjDef           -- ^ object definition
-	             | FunctionDef FunDef         -- ^ function definition
-	             | EnumeratorDef Enumerator   -- ^ definition of an enumerator
+                     | ObjectDef ObjDef           -- ^ object definition
+                     | FunctionDef FunDef         -- ^ function definition
+                     | EnumeratorDef Enumerator   -- ^ definition of an enumerator
                deriving (Typeable, Data {-! ,CNode !-})
 
 instance Declaration IdentDecl where
@@ -390,6 +390,8 @@ data IntType =
     | TyUShort
     | TyInt
     | TyUInt
+    | TyInt128
+    | TyUInt128
     | TyLong
     | TyULong
     | TyLLong
@@ -405,6 +407,8 @@ instance Show IntType where
     show TyUShort = "unsigned short"
     show TyInt = "int"
     show TyUInt = "unsigned int"
+    show TyInt128 = "__int128"
+    show TyUInt128 = "unsigned __int128"
     show TyLong = "long"
     show TyULong = "unsigned long"
     show TyLLong = "long long"
