@@ -19,14 +19,14 @@ module Language.C.Data (
      -- * Unqiue names
      Name(..),newNameSupply,
      -- * Source code positions
-     Position(..),Pos(..),initPos,
-     posFile,posRow,posColumn,
-     nopos,builtinPos,internalPos,
+     Position(..),Pos(..),
+     initPos, nopos,builtinPos,internalPos,
      isSourcePos,isBuiltinPos,isInternalPos,
      -- * Syntax tree nodes
      NodeInfo(..),CNode(..),
      fileOfNode,posOfNode,nameOfNode,
-     internalNode,mkNodeInfoOnlyPos,mkNodeInfo,
+     undefNode,mkNodeInfoOnlyPos,mkNodeInfo,
+     internalNode, -- DEPRECATED
      -- * Extensible errors
      module Language.C.Data.Error
 )
